@@ -3,7 +3,8 @@
 context("Test that create_met() creates an APSIM .met file")
 
 test_that("create_met() creates a .met file for APSIM use", {
-  vcr::use_cassette("create_met", {
+  skip_on_cran()
+  vcr::use_cassette(name = "create_met", {
     power_query <- create_met(
       lonlat = c(151.81, -27.48),
       dates = c("1985-01-01", "1985-12-31"),
